@@ -629,11 +629,11 @@ ecc_point_out (FILE *f, const struct ecc_point *p)
     fprintf (f, "zero");
   else
     {
-	fprintf (stderr, "(");
-	mpz_out_str (stderr, 16, p->x);
-	fprintf (stderr, ",\n     ");
-	mpz_out_str (stderr, 16, (p)->y);
-	fprintf (stderr, ")");
+	fprintf (f, "(");
+	mpz_out_str (f, 16, p->x);
+	fprintf (f, ",\n     ");
+	mpz_out_str (f, 16, (p)->y);
+	fprintf (f, ")");
     }
 }
 #define ASSERT_EQUAL(p, q) do {						\
@@ -949,16 +949,19 @@ output_curve (const struct ecc_curve *ecc, unsigned bits_per_limb)
 	      exit (EXIT_FAILURE);
 	    }
 	}
+    }
+  else
+    printf ("#define ecc_Bmodp_shifted ecc_Bmodp\n");
+
+  if (bits < limb_size * bits_per_limb)
+    {
       mpz_set_ui (t, 0);
-      mpz_setbit (t, ecc->bit_size);
+      mpz_setbit (t, bits);
       mpz_sub (t, t, ecc->q);      
       output_bignum ("ecc_Bmodq_shifted", t, limb_size, bits_per_limb);      
     }
   else
-    {
-      printf ("#define ecc_Bmodp_shifted ecc_Bmodp\n");
-      printf ("#define ecc_Bmodq_shifted ecc_Bmodq\n");
-    }
+    printf ("#define ecc_Bmodq_shifted ecc_Bmodq\n");
 
   mpz_add_ui (t, ecc->p, 1);
   mpz_fdiv_q_2exp (t, t, 1);
